@@ -1,28 +1,27 @@
 ////////////////////////////////////////////////////////////////////////////
-//  Copyright (C) 2008-2014 by Alexander Galanin                          //
+//  Copyright (C) 2008-2018 by Alexander Galanin                          //
 //  al@galanin.nnov.ru                                                    //
 //  http://galanin.nnov.ru/~al                                            //
 //                                                                        //
-//  This program is free software; you can redistribute it and/or modify  //
-//  it under the terms of the GNU Lesser General Public License as        //
-//  published by the Free Software Foundation; either version 3 of the    //
-//  License, or (at your option) any later version.                       //
+//  This program is free software: you can redistribute it and/or modify  //
+//  it under the terms of the GNU General Public License as published by  //
+//  the Free Software Foundation, either version 3 of the License, or     //
+//  (at your option) any later version.                                   //
 //                                                                        //
 //  This program is distributed in the hope that it will be useful,       //
 //  but WITHOUT ANY WARRANTY; without even the implied warranty of        //
 //  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         //
 //  GNU General Public License for more details.                          //
 //                                                                        //
-//  You should have received a copy of the GNU Lesser General Public      //
-//  License along with this program; if not, write to the                 //
-//  Free Software Foundation, Inc.,                                       //
-//  51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA               //
+//  You should have received a copy of the GNU General Public License     //
+//  along with this program.  If not, see <https://www.gnu.org/licenses/>.//
 ////////////////////////////////////////////////////////////////////////////
 
 #include <zip.h>
 #include <syslog.h>
-#include <cerrno>
 #include <cassert>
+#include <cerrno>
+#include <cstring>
 #include <stdexcept>
 
 #include "fuseZipData.h"
@@ -32,10 +31,16 @@ FuseZipData::FuseZipData(const char *archiveName, struct zip *z, const char *cwd
 
 FuseZipData::~FuseZipData() {
     if (chdir(m_cwd.c_str()) != 0) {
-        syslog(LOG_ERR, "Unable to chdir() to archive directory %s. Trying to save file into /tmp",
-                m_cwd.c_str());
-        if (chdir(getenv("TMP")) != 0) {
-            chdir("/tmp");
+        syslog(LOG_ERR, "Unable to chdir() to archive directory %s: %s. Trying to save file into $TMP or /tmp...",
+                m_cwd.c_str(), strerror(errno));
+        const char *tmpDir = getenv("TMP");
+        if (tmpDir == NULL || chdir(tmpDir) != 0) {
+            if (tmpDir != NULL) {
+                syslog(LOG_WARNING, "Unable to chdir() to %s: %s.", tmpDir, strerror(errno));
+            }
+            if (chdir("/tmp") != 0) {
+                syslog(LOG_ERR, "Unable to chdir() to /tmp: %s!", strerror(errno));
+            }
         }
     }
     int res = zip_close(m_zip);
